@@ -14,7 +14,7 @@ plotSpatialImage <- function(csite, substance, timepoint = NULL, app_log = NULL)
   end.time <- Sys.time()
   time.passed <- (end.time - start.time) * 1000
   time.passed <- round(time.passed, digits = 0)
-  time.log <- paste0("[TIME_MEASURE] interpConc(): ", time.passed, " milliseconds.\n")
+  time.log <- paste0("[plotSpatialImage] Data prediction took ", time.passed, " milliseconds.\n")
   
   if (!is.null(app_log)) {
     alog <- isolate(app_log())
@@ -381,11 +381,11 @@ plotSpatialImage_main <- function(csite, substance = " ", timepoint = NULL,
 }
 
 
-plotSpatialImagePPT <- function(csite, substance, timepoint,
+plotSpatialImagePPT <- function(csite, fileout, substance, timepoint,
                            width = 700, height = 500){
  
   # Initialize Powerpoint file.
-  if (is.null(ppt_lst <- initPPT())) {
+  if (is.null(ppt_pres <- initPPT())) {
     return(NULL)
   }
   
@@ -396,16 +396,104 @@ plotSpatialImagePPT <- function(csite, substance, timepoint,
   plotSpatialImage(csite, substance, timepoint)
   dev.off()
   
+  ppt_pres <- addPlotPPT(mytemp, ppt_pres, width, height) 
   
-  addPlotPPT(mytemp, ppt_lst, width, height) 
+  print(ppt_pres, target = fileout) %>% invisible()
   
   try(file.remove(mytemp))
   
 }
 
 
+makeSpatialAnimation <- function(csite, fileout, substance,
+                                 width = 800,
+                                 height = 600,
+                                 width_plume = 1200, 
+                                 height_plume = 600) {
+  
+  full_plume_stats <- NULL 
+  
+  # Initialize Powerpoint file.
+  if (is.null(ppt_pres <- initPPT())) {
+    return(NULL)
+  }
+  
+  progress <- shiny::Progress$new()
+  progress$set(message = "Generating Powerpoint: ", value = 0)
+  on.exit(progress$close())
+  
+  # Loop over each time step.. 
+  for (i in 1:length(csite$All.Data$All_Agg_Dates)) {
+    
+    progress$set(value = i/length(csite$All.Data$All_Agg_Dates), detail = paste0("Slide ", i))
+    
+    timepoint <- csite$All.Data$All_Agg_Dates[i]
+    
+    # Do the interpolation.
+    interp.pred <- interpConc(csite, substance, timepoint)
+    
+    # Create plume statistics if needed.
+    #
+    # Note: This is a duplicate from function getFullPlumeStats(). It could be called 
+    #       separately and before plotSpatialImage_main(). However, both functions
+    #       depend on interpConc() and I don't like to call it twice.
+    #       Fixme: Call interpConc() separately, and pass results for each timepoint
+    #              to getPlumeStats() and plotSpatialImage_main().
+    #
+    plume_stats <- NULL
+    if (csite$ui_attr$spatial_options["Plume Diagnostics"]) {
+      
+      plume_stats <- getPlumeStats(csite, substance, timepoint, interp.pred$data, 
+                                   csite$ui_attr$plume_thresh[substance], 
+                                   csite$ui_attr$ground_porosity)
+      
+      # Add date. 
+      plume_stats = cbind(plume_stats, "Agg.Date" = timepoint)
+      
+      # Append to full plume stats table.
+      if (is.null(full_plume_stats))
+        full_plume_stats <- plume_stats
+      else
+        full_plume_stats <- rbind(full_plume_stats, plume_stats)
+      
+    }
+    
+    # Make the plot and add to powerpoint.
+    mytemp <- tempfile(fileext = ".png")
+    
+    png(mytemp, width = width, height = height)
+    plotSpatialImage_main(csite, substance, timepoint, interp.pred, plume_stats)
+    dev.off()
+    
+    ppt_pres <- addPlotPPT(mytemp, ppt_pres, width, height) 
+    
+    try(file.remove(mytemp))
+    
+  } # end of for
+  
+  
+  
+  # Add slide with plume statistics on last page.
+  if (csite$ui_attr$spatial_options["Plume Diagnostics"]) {
+    
+    # Make the plot and add to powerpoint.
+    mytemp <- tempfile(fileext = ".png")
+    
+    png(mytemp, width = width_plume, height = height_plume)
+    plotPlumeTimeSeries(full_plume_stats)
+    dev.off()
+    
+    ppt_pres <- addPlotPPT(mytemp, ppt_pres, width = width_plume, height = height_plume)
+    
+    try(file.remove(mytemp))
+  }
+  
+  print(ppt_pres, target = fileout) %>% invisible()
+  
+}
 
-makeSpatialAnimation <- function(csite, substance,
+
+makeSpatialAnimation_RDCOMClient <- function(csite, substance,
                                  width = 800,
                                  height = 600,
                                  width_plume = 1200, 
